function w = gausswinf(N, Alpha)
%HAMMINGF Reimplementation of gausswin function from Signal Processing
%Toolbox
%   w = gausswin(N) returns an N-point Gaussian window in a column vector,
%   w. N is a positive integer.
%   w = gausswin(N,Alpha) returns an N-point Gaussian window with Alpha
%   proportional to the reciprocal of the standard deviation. The width of
%   the window is inversely related to the value of ?. A larger value of ?
%   produces a narrower window. The value of ? defaults to 2.5.

if ~exist('Alpha','var')
    Alpha = 2.5;
end
ind = (-(N-1)/2):((N-1)/2);

w = exp(-0.5*(Alpha*(ind/((N-1)/2)))^2);

end

